@@ -127,7 +127,7 @@ wp_props_load_wallpaper (gchar *key,
 
   gtk_list_store_append (GTK_LIST_STORE (data->wp_model), &iter);
 
-  pixbuf = gnome_wp_item_get_thumbnail (item, data->wp_thumbs);
+  pixbuf = gnome_wp_item_get_thumbnail (item, data->thumb_factory);
   gnome_wp_item_update_description (item);
 
   gtk_list_store_set (GTK_LIST_STORE (data->wp_model), &iter,
@@ -162,7 +162,7 @@ wp_add_image (AppearanceData *data,
   }
   else
   {
-    item = gnome_wp_item_new (filename, data->wp_hash, data->wp_thumbs);
+    item = gnome_wp_item_new (filename, data->wp_hash, data->thumb_factory);
 
     if (item != NULL)
     {
@@ -181,7 +181,7 @@ wp_add_images (AppearanceData *data,
   GdkCursor *cursor;
   GnomeWPItem *item;
 
-  window = (glade_xml_get_widget (data->xml, "appearance_window"))->window;
+  window = glade_xml_get_widget (data->xml, "appearance_window")->window;
 
   item = NULL;
   cursor = gdk_cursor_new_for_display (gdk_display_get_default (),
@@ -337,7 +337,7 @@ wp_scale_type_changed (GtkComboBox *combobox,
     break;
   }
 
-  pixbuf = gnome_wp_item_get_thumbnail (item, data->wp_thumbs);
+  pixbuf = gnome_wp_item_get_thumbnail (item, data->thumb_factory);
   gtk_list_store_set (GTK_LIST_STORE (data->wp_model),
                       &iter,
                       0, pixbuf,
@@ -380,7 +380,7 @@ wp_shade_type_changed (GtkWidget *combobox,
     break;
   }
 
-  pixbuf = gnome_wp_item_get_thumbnail (item, data->wp_thumbs);
+  pixbuf = gnome_wp_item_get_thumbnail (item, data->thumb_factory);
   gtk_list_store_set (GTK_LIST_STORE (data->wp_model), &iter,
                       0, pixbuf,
                       -1);
@@ -406,19 +406,13 @@ wp_color_changed (AppearanceData *data,
 
   gtk_color_button_get_color (GTK_COLOR_BUTTON (data->wp_pcpicker), item->pcolor);
 
-  item->pri_color = g_strdup_printf ("#%02X%02X%02X",
-                                     item->pcolor->red >> 8,
-                                     item->pcolor->green >> 8,
-                                     item->pcolor->blue >> 8);
+  item->pri_color = gdk_color_to_string (item->pcolor);
 
   g_free (item->sec_color);
 
   gtk_color_button_get_color (GTK_COLOR_BUTTON (data->wp_scpicker), item->scolor);
 
-  item->sec_color = g_strdup_printf ("#%02X%02X%02X",
-                                     item->scolor->red >> 8,
-                                     item->scolor->green >> 8,
-                                     item->scolor->blue >> 8);
+  item->sec_color = gdk_color_to_string (item->scolor);
 
   if (update)
   {
@@ -607,8 +601,12 @@ wp_props_wp_set (AppearanceData *data, GnomeWPItem *item)
     else
       uri = g_filename_to_utf8 (item->filename, -1, NULL, NULL, NULL);
 
-    gconf_change_set_set_string (cs, WP_FILE_KEY, uri);
-    g_free (uri);
+    if (uri == NULL) {
+      g_warning ("Failed to convert filename to UTF-8: %s\n", item->filename);
+    } else {
+      gconf_change_set_set_string (cs, WP_FILE_KEY, uri);
+      g_free (uri);
+    }
 
     gconf_change_set_set_string (cs, WP_OPTIONS_KEY, item->options);
   }
@@ -665,11 +663,11 @@ wp_file_open_dialog (GtkWidget *widget,
   switch (gtk_dialog_run (GTK_DIALOG (data->wp_filesel)))
   {
   case GTK_RESPONSE_OK:
-    files = gtk_file_chooser_get_filenames (GTK_FILE_CHOOSER (data->wp_filesel));
+    files = gtk_file_chooser_get_filenames (data->wp_filesel);
     wp_add_images (data, files);
   case GTK_RESPONSE_CANCEL:
   default:
-    gtk_widget_hide (data->wp_filesel);
+    gtk_widget_hide (GTK_WIDGET (data->wp_filesel));
     break;
   }
 }
@@ -695,7 +693,7 @@ wp_dragged_image (GtkWidget *widget,
       GdkWindow *window;
       GdkCursor *cursor;
 
-      window = (glade_xml_get_widget (data->xml, "appearance_window"))->window;
+      window = glade_xml_get_widget (data->xml, "appearance_window")->window;
 
       cursor = gdk_cursor_new_for_display (gdk_display_get_default (),
              GDK_WATCH);
@@ -796,7 +794,7 @@ wp_update_preview (GtkFileChooser *chooser,
 
     if (mime_type)
     {
-      pixbuf = gnome_thumbnail_factory_generate_thumbnail (data->wp_thumbs,
+      pixbuf = gnome_thumbnail_factory_generate_thumbnail (data->thumb_factory,
                                                            uri,
                                                            mime_type);
       g_free (mime_type);
@@ -880,7 +878,7 @@ wp_load_stuffs (void *user_data)
   item = g_hash_table_lookup (data->wp_hash, "(none)");
   if (item == NULL)
   {
-    item = gnome_wp_item_new ("(none)", data->wp_hash, data->wp_thumbs);
+    item = gnome_wp_item_new ("(none)", data->wp_hash, data->thumb_factory);
     if (item != NULL)
     {
       wp_props_load_wallpaper (item->filename, item, data);
@@ -915,7 +913,12 @@ static void
 wp_select_after_realize (GtkWidget *widget,
                          AppearanceData *data)
 {
-  select_item (data, get_selected_item (data, NULL), TRUE);
+  GnomeWPItem *item = get_selected_item (data, NULL);
+
+  if (item == NULL)
+    item = g_hash_table_lookup (data->wp_hash, "(none)");
+
+  select_item (data, item, TRUE);
 }
 
 void
@@ -925,6 +928,7 @@ desktop_init (AppearanceData *data,
   GtkWidget *add_button;
   GtkCellRenderer *cr;
   GtkFileFilter *filter;
+  const gchar *pictures;
 
   g_object_set (gtk_settings_get_default (), "gtk-tooltip-timeout", 500, NULL);
 
@@ -940,8 +944,6 @@ desktop_init (AppearanceData *data,
 
   data->wp_hash = g_hash_table_new (g_str_hash, g_str_equal);
 
-  data->wp_thumbs = gnome_thumbnail_factory_new (GNOME_THUMBNAIL_SIZE_NORMAL);
-
   gconf_client_add_dir (data->client, WP_KEYBOARD_PATH,
       GCONF_CLIENT_PRELOAD_ONELEVEL, NULL);
   gconf_client_add_dir (data->client, WP_PATH_KEY,
@@ -976,7 +978,7 @@ desktop_init (AppearanceData *data,
   gtk_icon_view_set_model (data->wp_view, GTK_TREE_MODEL (data->wp_model));
 
   g_signal_connect_after (data->wp_view, "realize",
-                          G_CALLBACK (wp_select_after_realize), data);
+                          (GCallback) wp_select_after_realize, data);
 
   gtk_cell_layout_clear (GTK_CELL_LAYOUT (data->wp_view));
 
@@ -998,50 +1000,51 @@ desktop_init (AppearanceData *data,
   gtk_drag_dest_set (GTK_WIDGET (data->wp_view), GTK_DEST_DEFAULT_ALL, drop_types,
                      G_N_ELEMENTS (drop_types), GDK_ACTION_COPY | GDK_ACTION_MOVE);
   g_signal_connect (data->wp_view, "drag_data_received",
-                    G_CALLBACK (wp_dragged_image), data);
+                    (GCallback) wp_dragged_image, data);
 
   data->wp_style_menu = glade_xml_get_widget (data->xml, "wp_style_menu");
 
   g_signal_connect (data->wp_style_menu, "changed",
-                    G_CALLBACK (wp_scale_type_changed), data);
+                    (GCallback) wp_scale_type_changed, data);
 
   data->wp_color_menu = glade_xml_get_widget (data->xml, "wp_color_menu");
 
   g_signal_connect (data->wp_color_menu, "changed",
-                    G_CALLBACK (wp_shade_type_changed), data);
+                    (GCallback) wp_shade_type_changed, data);
 
   data->wp_scpicker = glade_xml_get_widget (data->xml, "wp_scpicker");
 
   g_signal_connect (data->wp_scpicker, "color-set",
-                    G_CALLBACK (wp_scolor_changed), data);
+                    (GCallback) wp_scolor_changed, data);
 
   data->wp_pcpicker = glade_xml_get_widget (data->xml, "wp_pcpicker");
 
   g_signal_connect (data->wp_pcpicker, "color-set",
-                    G_CALLBACK (wp_scolor_changed), data);
+                    (GCallback) wp_scolor_changed, data);
 
   add_button = glade_xml_get_widget (data->xml, "wp_add_button");
   gtk_button_set_image (GTK_BUTTON (add_button),
                         gtk_image_new_from_stock ("gtk-add", GTK_ICON_SIZE_BUTTON));
 
   g_signal_connect (add_button, "clicked",
-                    G_CALLBACK (wp_file_open_dialog), data);
+                    (GCallback) wp_file_open_dialog, data);
 
   data->wp_rem_button = glade_xml_get_widget (data->xml, "wp_rem_button");
 
   g_signal_connect (data->wp_rem_button, "clicked",
-                    G_CALLBACK (wp_remove_wallpaper), data);
+                    (GCallback) wp_remove_wallpaper, data);
 
   g_idle_add (wp_load_stuffs, data);
 
   g_signal_connect (data->wp_view, "selection-changed",
-                    G_CALLBACK (wp_props_wp_selected), data);
+                    (GCallback) wp_props_wp_selected, data);
   g_signal_connect (data->wp_view, "query-tooltip",
-                    G_CALLBACK (wp_view_tooltip_cb), data);
+                    (GCallback) wp_view_tooltip_cb, data);
 
   wp_set_sensitivities (data);
 
-  data->wp_filesel = gtk_file_chooser_dialog_new_with_backend (_("Add Wallpaper"),
+  data->wp_filesel = GTK_FILE_CHOOSER (
+  		     gtk_file_chooser_dialog_new_with_backend (_("Add Wallpaper"),
                      GTK_WINDOW (glade_xml_get_widget (data->xml, "appearance_window")),
                      GTK_FILE_CHOOSER_ACTION_OPEN,
                      "gtk+",
@@ -1049,32 +1052,35 @@ desktop_init (AppearanceData *data,
                      GTK_RESPONSE_CANCEL,
                      GTK_STOCK_OPEN,
                      GTK_RESPONSE_OK,
-                     NULL);
+                     NULL));
 
-  gtk_file_chooser_set_select_multiple (GTK_FILE_CHOOSER (data->wp_filesel),
-                                        TRUE);
-  gtk_file_chooser_set_use_preview_label (GTK_FILE_CHOOSER (data->wp_filesel),
-                                          FALSE);
+  gtk_file_chooser_set_select_multiple (data->wp_filesel, TRUE);
+  gtk_file_chooser_set_use_preview_label (data->wp_filesel, FALSE);
+
+  pictures = g_get_user_special_dir (G_USER_DIRECTORY_PICTURES);
+  if (pictures != NULL && g_file_test (pictures, G_FILE_TEST_IS_DIR)) {
+    gtk_file_chooser_add_shortcut_folder (data->wp_filesel, pictures, NULL);
+    gtk_file_chooser_set_current_folder (data->wp_filesel, pictures);
+  }
 
   filter = gtk_file_filter_new ();
   gtk_file_filter_add_pixbuf_formats (filter);
   gtk_file_filter_set_name (filter, _("Images"));
-  gtk_file_chooser_add_filter (GTK_FILE_CHOOSER (data->wp_filesel), filter);
+  gtk_file_chooser_add_filter (data->wp_filesel, filter);
 
   filter = gtk_file_filter_new ();
   gtk_file_filter_set_name (filter, _("All files"));
   gtk_file_filter_add_pattern (filter, "*");
-  gtk_file_chooser_add_filter (GTK_FILE_CHOOSER (data->wp_filesel), filter);
+  gtk_file_chooser_add_filter (data->wp_filesel, filter);
 
   data->wp_image = gtk_image_new ();
-  gtk_file_chooser_set_preview_widget (GTK_FILE_CHOOSER (data->wp_filesel),
-                                       data->wp_image);
+  gtk_file_chooser_set_preview_widget (data->wp_filesel, data->wp_image);
   gtk_widget_set_size_request (data->wp_image, 128, -1);
 
   gtk_widget_show (data->wp_image);
 
   g_signal_connect (data->wp_filesel, "update-preview",
-                    G_CALLBACK (wp_update_preview), data);
+                    (GCallback) wp_update_preview, data);
 }
 
 void
@@ -1083,7 +1089,6 @@ desktop_shutdown (AppearanceData *data)
   gnome_wp_xml_save_list (data);
   g_slist_foreach (data->wp_uris, (GFunc) g_free, NULL);
   g_slist_free (data->wp_uris);
-  g_object_unref (data->wp_thumbs);
   g_object_ref_sink (data->wp_filesel);
   g_object_unref (data->wp_filesel);
 }
