@@ -160,9 +160,12 @@ static GladeXML *
 create_dialog (void) 
 {
 	GladeXML *dialog;
-	GtkWidget *widget, *box, *view;
+	GtkWidget *widget, *box, *view, *image;
 
 	dialog = glade_xml_new (GNOMECC_GLADE_DIR "/sound-properties.glade", "sound_prefs_dialog", NULL);
+	if (dialog == NULL)
+	  return NULL;
+
 	widget = glade_xml_get_widget (dialog, "sound_prefs_dialog");
 
 	props = sound_properties_new ();
@@ -180,6 +183,18 @@ create_dialog (void)
 	gtk_image_set_from_file (GTK_IMAGE (WID ("bell_image")),
 				 GNOMECC_DATA_DIR "/pixmaps/visual-bell.png");
 
+	image = gtk_image_new_from_stock (GTK_STOCK_APPLY, GTK_ICON_SIZE_BUTTON);
+	gtk_button_set_image (GTK_BUTTON (WID ("sounds_playback_test")), image);
+
+	image = gtk_image_new_from_stock (GTK_STOCK_APPLY, GTK_ICON_SIZE_BUTTON);
+	gtk_button_set_image (GTK_BUTTON (WID ("music_playback_test")), image);
+
+	image = gtk_image_new_from_stock (GTK_STOCK_APPLY, GTK_ICON_SIZE_BUTTON);
+	gtk_button_set_image (GTK_BUTTON (WID ("chat_audio_playback_test")), image);
+
+	image = gtk_image_new_from_stock (GTK_STOCK_APPLY, GTK_ICON_SIZE_BUTTON);
+	gtk_button_set_image (GTK_BUTTON (WID ("chat_audio_capture_test")), image);
+
 	if (!CheckXKB()) {
 		gtk_widget_set_sensitive (WID ("bell_flash_alignment"), FALSE);
 	}
@@ -1001,7 +1016,7 @@ int
 main (int argc, char **argv) 
 {
 	GConfChangeSet *changeset;
-	GladeXML       *dialog = NULL;
+	GladeXML       *dialog;
 	GnomeProgram   *program;
  	GOptionContext *context;
 	gboolean apply_only = FALSE;
@@ -1046,20 +1061,23 @@ main (int argc, char **argv)
 	if (get_legacy) {
 		get_legacy_settings ();
 	} else {
-		changeset = gconf_change_set_new ();
 		dialog = create_dialog ();
-		setup_dialog (dialog, changeset);
-		setup_devices ();
 
-		dialog_win = WID ("sound_prefs_dialog");
-		g_signal_connect (dialog_win, "response", G_CALLBACK (dialog_response_cb), changeset);
-		g_signal_connect (dialog_win, "destroy", G_CALLBACK (gtk_main_quit), NULL);
-		capplet_set_icon (dialog_win, "gnome-settings-sound");
-		gtk_widget_show (dialog_win);
+		if (dialog) {
+			changeset = gconf_change_set_new ();
+			setup_dialog (dialog, changeset);
+			setup_devices ();
 
-		gtk_main ();
-		gconf_change_set_unref (changeset);
-		g_object_unref (dialog);
+			dialog_win = WID ("sound_prefs_dialog");
+			g_signal_connect (dialog_win, "response", G_CALLBACK (dialog_response_cb), changeset);
+			g_signal_connect (dialog_win, "destroy", G_CALLBACK (gtk_main_quit), NULL);
+			capplet_set_icon (dialog_win, "gnome-sound-properties");
+			gtk_widget_show (dialog_win);
+
+			gtk_main ();
+			gconf_change_set_unref (changeset);
+			g_object_unref (dialog);
+		}
 	}
 	
 	g_object_unref (gconf_client);
